==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/testa/TestaGetCertificatesByPager1DataItem.java <==
package global.hh.openapi.sdk.api.bean.testa;


/**
 * @description: 企业资质管理1
 * @author: 12487
 * @date: 2019-06-03 05:06:29
 */
public class TestaGetCertificatesByPager1DataItem {

    /**
     * 营业执照地址
     */
    private String address;

    /**
     * 认证状态：0未认证、1 认证中、2认证成功、3认证失败
     */
    private Long attestStatus;

    /**
     * 企业简介
     */
    private String briefIntroduction;

    /**
     * 营业执照
     */
    private String businessLicenseUrl;

    /**
     * 失败原因
     */
    private String causeOfFailure;

    /**
     * 企业名称
     */
    private String companyName;

    /**
     * ID
     */
    private Long id;

    /**
     * 法定代表人
     */
    private String legalRepresentative;

    /**
     * 营业执照有效期
     */
    private String periodOfValidity;

    /**
     * 营业执照注册号
     */
    private String registrationNumber;

    /**
     * 状态：1启用、0停用
     */
    private Long status;

    /**
     * 手机号
     */
    private String telephoneNumber;

    /**
     * 营业执照的缩略图
     */
    private String thumbnailByBusinessLicenseUrl;

    /**
     * 用户id
     */
    private Long userId;

    public TestaGetCertificatesByPager1DataItem(){
    }

    public TestaGetCertificatesByPager1DataItem(String address,Long attestStatus,String briefIntroduction,String businessLicenseUrl,String causeOfFailure,String companyName,Long id,String legalRepresentative,String periodOfValidity,String registrationNumber,Long status,String telephoneNumber,String thumbnailByBusinessLicenseUrl,Long userId){
        this.address=address;
        this.attestStatus=attestStatus;
        this.briefIntroduction=briefIntroduction;
        this.businessLicenseUrl=businessLicenseUrl;
        this.causeOfFailure=causeOfFailure;
        this.companyName=companyName;
        this.id=id;
        this.legalRepresentative=legalRepresentative;
        this.periodOfValidity=periodOfValidity;
        this.registrationNumber=registrationNumber;
        this.status=status;
        this.telephoneNumber=telephoneNumber;
        this.thumbnailByBusinessLicenseUrl=thumbnailByBusinessLicenseUrl;
        this.userId=userId;
    }

    private String getAddress() {
        return address;
    }

    private void setAddress(String address) {
        this.address = address;
    }
    private Long getAttestStatus() {
        return attestStatus;
    }

    private void setAttestStatus(Long attestStatus) {
        this.attestStatus = attestStatus;
    }
    private String getBriefIntroduction() {
        return briefIntroduction;
    }

    private void setBriefIntroduction(String briefIntroduction) {
        this.briefIntroduction = briefIntroduction;
    }
    private String getBusinessLicenseUrl() {
        return businessLicenseUrl;
    }

    private void setBusinessLicenseUrl(String businessLicenseUrl) {
        this.businessLicenseUrl = businessLicenseUrl;
    }
    private String getCauseOfFailure() {
        return causeOfFailure;
    }

    private void setCauseOfFailure(String causeOfFailure) {
        this.causeOfFailure = causeOfFailure;
    }
    private String getCompanyName() {
        return companyName;
    }

    private void setCompanyName(String companyName) {
        this.companyName = companyName;
    }
    private Long getId() {
        return id;
    }

    private void setId(Long id) {
        this.id = id;
    }
    private String getLegalRepresentative() {
        return legalRepresentative;
    }

    private void setLegalRepresentative(String legalRepresentative) {
        this.legalRepresentative = legalRepresentative;
    }
    private String getPeriodOfValidity() {
        return periodOfValidity;
    }

    private void setPeriodOfValidity(String periodOfValidity) {
        this.periodOfValidity = periodOfValidity;
    }
    private String getRegistrationNumber() {
        return registrationNumber;
    }

    private void setRegistrationNumber(String registrationNumber) {
        this.registrationNumber = registrationNumber;
    }
    private Long getStatus() {
        return status;
    }

    private void setStatus(Long status) {
        this.status = status;
    }
    private String getTelephoneNumber() {
        return telephoneNumber;
    }

    private void setTelephoneNumber(String telephoneNumber) {
        this.telephoneNumber = telephoneNumber;
    }
    private String getThumbnailByBusinessLicenseUrl() {
        return thumbnailByBusinessLicenseUrl;
    }

    private void setThumbnailByBusinessLicenseUrl(String thumbnailByBusinessLicenseUrl) {
        this.thumbnailByBusinessLicenseUrl = thumbnailByBusinessLicenseUrl;
    }
    private Long getUserId() {
        return userId;
    }

    private void setUserId(Long userId) {
        this.userId = userId;
    }
}

==> biostime-openapi-sdk-1.5.8.6-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/testa/TestaGetCertificatesByPager1DataItem.java <==
package global.hh.openapi.sdk.api.bean.testa;


/**
 * @description: 企业资质管理1
 * @author: 12487
 * @date: 2019-06-03 05:06:29
 */
public class TestaGetCertificatesByPager1DataItem {

    /**
     * 营业执照地址
     */
    private String address;

    /**
     * 认证状态：0未认证、1 认证中、2认证成功、3认证失败
     */
    private Long attestStatus;

    /**
     * 企业简介
     */
    private String briefIntroduction;

    /**
     * 营业执照
     */
    private String businessLicenseUrl;

    /**
     * 失败原因
     */
    private String causeOfFailure;

    /**
     * 企业名称
     */
    private String companyName;

    /**
     * ID
     */
    private Long id;

    /**
     * 法定代表人
     */
    private String legalRepresentative;

    /**
     * 营业执照有效期
     */
    private String periodOfValidity;

    /**
     * 营业执照注册号
     */
    private String registrationNumber;

    /**
     * 状态：1启用、0停用
     */
    private Long status;

    /**
     * 手机号
     */
    private String telephoneNumber;

    /**
     * 营业执照的缩略图
     */
    private String thumbnailByBusinessLicenseUrl;

    /**
     * 用户id
     */
    private Long userId;

    public TestaGetCertificatesByPager1DataItem(){
    }

    public TestaGetCertificatesByPager1DataItem(String address,Long attestStatus,String briefIntroduction,String businessLicenseUrl,String causeOfFailure,String companyName,Long id,String legalRepresentative,String periodOfValidity,String registrationNumber,Long status,String telephoneNumber,String thumbnailByBusinessLicenseUrl,Long userId){
        this.address=address;
        this.attestStatus=attestStatus;
        this.briefIntroduction=briefIntroduction;
        this.businessLicenseUrl=businessLicenseUrl;
        this.causeOfFailure=causeOfFailure;
        this.companyName=companyName;
        this.id=id;
        this.legalRepresentative=legalRepresentative;
        this.periodOfValidity=periodOfValidity;
        this.registrationNumber=registrationNumber;
        this.status=status;
        this.telephoneNumber=telephoneNumber;
        this.thumbnailByBusinessLicenseUrl=thumbnailByBusinessLicenseUrl;
        this.userId=userId;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public Long getAttestStatus() {
        return attestStatus;
    }

    public void setAttestStatus(Long attestStatus) {
        this.attestStatus = attestStatus;
    }
    public String getBriefIntroduction() {
        return briefIntroduction;
    }

    public void setBriefIntroduction(String briefIntroduction) {
        this.briefIntroduction = briefIntroduction;
    }
    public String getBusinessLicenseUrl() {
        return businessLicenseUrl;
    }

    public void setBusinessLicenseUrl(String businessLicenseUrl) {
        this.businessLicenseUrl = businessLicenseUrl;
    }
    public String getCauseOfFailure() {
        return causeOfFailure;
    }

    public void setCauseOfFailure(String causeOfFailure) {
        this.causeOfFailure = causeOfFailure;
    }
    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }
    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }
    public String getLegalRepresentative() {
        return legalRepresentative;
    }

    public void setLegalRepresentative(String legalRepresentative) {
        this.legalRepresentative = legalRepresentative;
    }
    public String getPeriodOfValidity() {
        return periodOfValidity;
    }

    public void setPeriodOfValidity(String periodOfValidity) {
        this.periodOfValidity = periodOfValidity;
    }
    public String getRegistrationNumber() {
        return registrationNumber;
    }

    public void setRegistrationNumber(String registrationNumber) {
        this.registrationNumber = registrationNumber;
    }
    public Long getStatus() {
        return status;
    }

    public void setStatus(Long status) {
        this.status = status;
    }
    public String getTelephoneNumber() {
        return telephoneNumber;
    }

    public void setTelephoneNumber(String telephoneNumber) {
        this.telephoneNumber = telephoneNumber;
    }
    public String getThumbnailByBusinessLicenseUrl() {
        return thumbnailByBusinessLicenseUrl;
    }

    public void setThumbnailByBusinessLicenseUrl(String thumbnailByBusinessLicenseUrl) {
        this.thumbnailByBusinessLicenseUrl = thumbnailByBusinessLicenseUrl;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
}
